@@ -1,7 +1,26 @@
+package Crypt::Rijndael;
+
+use strict;
+use warnings;
+
+our $VERSION = '1.13';
+
+use XSLoader;
+
+XSLoader::load('Crypt::Rijndael', $VERSION);
+
+1;
+
+__END__
+
 =head1 NAME
 
 Crypt::Rijndael - Crypt::CBC compliant Rijndael encryption module
 
+=head1 VERSION
+
+Version 1.13
+
 =head1 SYNOPSIS
 
  use Crypt::Rijndael;
@@ -23,22 +42,6 @@ as the Advanced Encryption Standard.
 
 =over 4
 
-=cut
-
-package Crypt::Rijndael;
-use strict;
-use vars qw( $VERSION @ISA );
-
-use warnings;
-no warnings;
-
-require DynaLoader;
-
-$VERSION = '1.12';
-@ISA = qw/DynaLoader/;
-
-bootstrap Crypt::Rijndael $VERSION;
-
 =item keysize
 
 Returns the keysize, which is 32 (bytes). The Rijndael cipher
@@ -111,7 +114,9 @@ Should EXPORT or EXPORT_OK the MODE constants.
 
 =head1 AUTHOR
 
-Currently maintained by brian d foy, C<< <bdfoy@cpan.org> >>.
+Currently maintained by Leon Timmermans C<< leont@cpan.org >>.
+
+Previously maintained by brian d foy, C<< <bdfoy@cpan.org> >>.
 
 Original code by  Rafael R. Sevilla.
 
@@ -122,7 +127,7 @@ and has been selected as the US Government's Advanced Encryption Standard.
 
 This code is in Github:
 
-	git://github.com/briandfoy/crypt-rijndael.git
+	git://github.com/leont/crypt-rijndael.git
 	
 =head1 LICENSE
 
@@ -131,5 +136,3 @@ June 2007). See the included COPYING file for details.
 
 =cut
 
-1;
-
